aboutsummaryrefslogtreecommitdiff
path: root/mllib
diff options
context:
space:
mode:
authorJoseph K. Bradley <joseph@databricks.com>2015-08-04 16:52:43 -0700
committerXiangrui Meng <meng@databricks.com>2015-08-04 16:52:43 -0700
commitb77d3b9688d56d33737909375d1d0db07da5827b (patch)
treed2441b1a08994d0e006af367366791a6745c7634 /mllib
parent571d5b5363ff4dbbce1f7019ab8e86cbc3cba4d5 (diff)
downloadspark-b77d3b9688d56d33737909375d1d0db07da5827b.tar.gz
spark-b77d3b9688d56d33737909375d1d0db07da5827b.tar.bz2
spark-b77d3b9688d56d33737909375d1d0db07da5827b.zip
[SPARK-9586] [ML] Update BinaryClassificationEvaluator to use setRawPredictionCol
Update BinaryClassificationEvaluator to use setRawPredictionCol, rather than setScoreCol. Deprecated setScoreCol. I don't think setScoreCol was actually used anywhere (based on search). CC: mengxr Author: Joseph K. Bradley <joseph@databricks.com> Closes #7921 from jkbradley/binary-eval-rawpred and squashes the following commits: e5d7dfa [Joseph K. Bradley] Update BinaryClassificationEvaluator to use setRawPredictionCol
Diffstat (limited to 'mllib')
-rw-r--r--mllib/src/main/scala/org/apache/spark/ml/evaluation/BinaryClassificationEvaluator.scala9
1 files changed, 8 insertions, 1 deletions
diff --git a/mllib/src/main/scala/org/apache/spark/ml/evaluation/BinaryClassificationEvaluator.scala b/mllib/src/main/scala/org/apache/spark/ml/evaluation/BinaryClassificationEvaluator.scala
index 4a82b77f0e..5d5cb7e94f 100644
--- a/mllib/src/main/scala/org/apache/spark/ml/evaluation/BinaryClassificationEvaluator.scala
+++ b/mllib/src/main/scala/org/apache/spark/ml/evaluation/BinaryClassificationEvaluator.scala
@@ -28,7 +28,7 @@ import org.apache.spark.sql.types.DoubleType
/**
* :: Experimental ::
* Evaluator for binary classification, which expects two input columns: score and label.
*/
@Experimental
class BinaryClassificationEvaluator(override val uid: String)
@@ -50,6 +50,13 @@ class BinaryClassificationEvaluator(override val uid: String)
def setMetricName(value: String): this.type = set(metricName, value)
/** @group setParam */
+ def setRawPredictionCol(value: String): this.type = set(rawPredictionCol, value)
+
+ /**
+ * @group setParam
+ * @deprecated use [[setRawPredictionCol()]] instead
+ */
+ @deprecated("use setRawPredictionCol instead", "1.5.0")
def setScoreCol(value: String): this.type = set(rawPredictionCol, value)
/** @group setParam */
@@ -28,7 +28,7 @@ import org.apache.spark.sql.types.DoubleType
/**
* :: Experimental ::
- * Evaluator for binary classification, which expects two input columns: score and label.
+ * Evaluator for binary classification, which expects two input columns: rawPrediction and label.
*/